# @kestra-io/kestrapy
All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/>
Endpoints designated as Superadmin-only are not tenant-scoped.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.2.0-SNAPSHOT
- Package version: 1.0.7
- Generator version: 7.16.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import kestrapy
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import kestrapy
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import kestrapy
from kestrapy.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = kestrapy.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = kestrapy.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)

# Configure Bearer authorization (Bearer): bearerAuth
configuration = kestrapy.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with kestrapy.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = kestrapy.ExecutionsApi(api_client)
    namespace = 'namespace_example' # str | The flow namespace
    id = 'id_example' # str | The flow id
    wait = False # bool | If the server will wait the end of the execution (default to False)
    tenant = 'tenant_example' # str | 
    labels = ['labels_example'] # List[str] | The labels as a list of 'key:value' (optional)
    revision = 56 # int | The flow revision or latest if null (optional)
    schedule_date = '2013-10-20T19:20:30+01:00' # datetime | Schedule the flow on a specific date (optional)
    breakpoints = 'breakpoints_example' # str | Set a list of breakpoints at specific tasks 'id.value', separated by a coma. (optional)
    kind = kestrapy.ExecutionKind() # ExecutionKind | Specific execution kind (optional)

    try:
        # Create a new execution for a flow
        api_response = api_instance.create_execution(namespace, id, wait, tenant, labels=labels, revision=revision, schedule_date=schedule_date, breakpoints=breakpoints, kind=kind)
        print("The response of ExecutionsApi->create_execution:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ExecutionsApi->create_execution: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ExecutionsApi* | [**create_execution**](docs/ExecutionsApi.md#create_execution) | **POST** /api/v1/{tenant}/executions/{namespace}/{id} | Create a new execution for a flow
*ExecutionsApi* | [**delete_execution**](docs/ExecutionsApi.md#delete_execution) | **DELETE** /api/v1/{tenant}/executions/{executionId} | Delete an execution
*ExecutionsApi* | [**delete_executions_by_ids**](docs/ExecutionsApi.md#delete_executions_by_ids) | **DELETE** /api/v1/{tenant}/executions/by-ids | Delete a list of executions
*ExecutionsApi* | [**delete_executions_by_query**](docs/ExecutionsApi.md#delete_executions_by_query) | **DELETE** /api/v1/{tenant}/executions/by-query | Delete executions filter by query parameters
*ExecutionsApi* | [**download_file_from_execution**](docs/ExecutionsApi.md#download_file_from_execution) | **GET** /api/v1/{tenant}/executions/{executionId}/file | Download file for an execution
*ExecutionsApi* | [**execution**](docs/ExecutionsApi.md#execution) | **GET** /api/v1/{tenant}/executions/{executionId} | Get an execution
*ExecutionsApi* | [**execution_flow_graph**](docs/ExecutionsApi.md#execution_flow_graph) | **GET** /api/v1/{tenant}/executions/{executionId}/graph | Generate a graph for an execution
*ExecutionsApi* | [**export_executions**](docs/ExecutionsApi.md#export_executions) | **GET** /api/v1/{tenant}/executions/export/by-query/csv | Export all executions as a streamed CSV file
*ExecutionsApi* | [**file_metadatas_from_execution**](docs/ExecutionsApi.md#file_metadatas_from_execution) | **GET** /api/v1/{tenant}/executions/{executionId}/file/metas | Get file meta information for an execution
*ExecutionsApi* | [**flow_from_execution**](docs/ExecutionsApi.md#flow_from_execution) | **GET** /api/v1/{tenant}/executions/flows/{namespace}/{flowId} | Get flow information&#39;s for an execution
*ExecutionsApi* | [**flow_from_execution_by_id**](docs/ExecutionsApi.md#flow_from_execution_by_id) | **GET** /api/v1/{tenant}/executions/{executionId}/flow | Get flow information&#39;s for an execution
*ExecutionsApi* | [**follow_dependencies_executions**](docs/ExecutionsApi.md#follow_dependencies_executions) | **GET** /api/v1/{tenant}/executions/{executionId}/follow-dependencies | Follow all execution dependencies executions
*ExecutionsApi* | [**follow_execution**](docs/ExecutionsApi.md#follow_execution) | **GET** /api/v1/{tenant}/executions/{executionId}/follow | Follow an execution
*ExecutionsApi* | [**force_run_by_ids**](docs/ExecutionsApi.md#force_run_by_ids) | **POST** /api/v1/{tenant}/executions/force-run/by-ids | Force run a list of executions
*ExecutionsApi* | [**force_run_execution**](docs/ExecutionsApi.md#force_run_execution) | **POST** /api/v1/{tenant}/executions/{executionId}/force-run | Force run an execution
*ExecutionsApi* | [**force_run_executions_by_query**](docs/ExecutionsApi.md#force_run_executions_by_query) | **POST** /api/v1/{tenant}/executions/force-run/by-query | Force run executions filter by query parameters
*ExecutionsApi* | [**kill_execution**](docs/ExecutionsApi.md#kill_execution) | **DELETE** /api/v1/{tenant}/executions/{executionId}/kill | Kill an execution
*ExecutionsApi* | [**kill_executions_by_ids**](docs/ExecutionsApi.md#kill_executions_by_ids) | **DELETE** /api/v1/{tenant}/executions/kill/by-ids | Kill a list of executions
*ExecutionsApi* | [**kill_executions_by_query**](docs/ExecutionsApi.md#kill_executions_by_query) | **DELETE** /api/v1/{tenant}/executions/kill/by-query | Kill executions filter by query parameters
*ExecutionsApi* | [**latest_executions**](docs/ExecutionsApi.md#latest_executions) | **POST** /api/v1/{tenant}/executions/latest | Get the latest execution for given flows
*ExecutionsApi* | [**pause_execution**](docs/ExecutionsApi.md#pause_execution) | **POST** /api/v1/{tenant}/executions/{executionId}/pause | Pause a running execution.
*ExecutionsApi* | [**pause_executions_by_ids**](docs/ExecutionsApi.md#pause_executions_by_ids) | **POST** /api/v1/{tenant}/executions/pause/by-ids | Pause a list of running executions
*ExecutionsApi* | [**pause_executions_by_query**](docs/ExecutionsApi.md#pause_executions_by_query) | **POST** /api/v1/{tenant}/executions/pause/by-query | Pause executions filter by query parameters
*ExecutionsApi* | [**replay_execution**](docs/ExecutionsApi.md#replay_execution) | **POST** /api/v1/{tenant}/executions/{executionId}/replay | Create a new execution from an old one and start it from a specified task run id
*ExecutionsApi* | [**replay_execution_withinputs**](docs/ExecutionsApi.md#replay_execution_withinputs) | **POST** /api/v1/{tenant}/executions/{executionId}/replay-with-inputs | Create a new execution from an old one and start it from a specified task run id
*ExecutionsApi* | [**replay_executions_by_ids**](docs/ExecutionsApi.md#replay_executions_by_ids) | **POST** /api/v1/{tenant}/executions/replay/by-ids | Create new executions from old ones. Keep the flow revision
*ExecutionsApi* | [**replay_executions_by_query**](docs/ExecutionsApi.md#replay_executions_by_query) | **POST** /api/v1/{tenant}/executions/replay/by-query | Create new executions from old ones filter by query parameters. Keep the flow revision
*ExecutionsApi* | [**restart_execution**](docs/ExecutionsApi.md#restart_execution) | **POST** /api/v1/{tenant}/executions/{executionId}/restart | Restart a new execution from an old one
*ExecutionsApi* | [**restart_executions_by_ids**](docs/ExecutionsApi.md#restart_executions_by_ids) | **POST** /api/v1/{tenant}/executions/restart/by-ids | Restart a list of executions
*ExecutionsApi* | [**restart_executions_by_query**](docs/ExecutionsApi.md#restart_executions_by_query) | **POST** /api/v1/{tenant}/executions/restart/by-query | Restart executions filter by query parameters
*ExecutionsApi* | [**resume_execution**](docs/ExecutionsApi.md#resume_execution) | **POST** /api/v1/{tenant}/executions/{executionId}/resume | Resume a paused execution.
*ExecutionsApi* | [**resume_executions_by_ids**](docs/ExecutionsApi.md#resume_executions_by_ids) | **POST** /api/v1/{tenant}/executions/resume/by-ids | Resume a list of paused executions
*ExecutionsApi* | [**resume_executions_by_query**](docs/ExecutionsApi.md#resume_executions_by_query) | **POST** /api/v1/{tenant}/executions/resume/by-query | Resume executions filter by query parameters
*ExecutionsApi* | [**search_executions**](docs/ExecutionsApi.md#search_executions) | **GET** /api/v1/{tenant}/executions/search | Search for executions
*ExecutionsApi* | [**search_executions_by_flow_id**](docs/ExecutionsApi.md#search_executions_by_flow_id) | **GET** /api/v1/{tenant}/executions | Search for executions for a flow
*ExecutionsApi* | [**set_labels_on_terminated_execution**](docs/ExecutionsApi.md#set_labels_on_terminated_execution) | **POST** /api/v1/{tenant}/executions/{executionId}/labels | Add or update labels of a terminated execution
*ExecutionsApi* | [**set_labels_on_terminated_executions_by_ids**](docs/ExecutionsApi.md#set_labels_on_terminated_executions_by_ids) | **POST** /api/v1/{tenant}/executions/labels/by-ids | Set labels on a list of executions
*ExecutionsApi* | [**set_labels_on_terminated_executions_by_query**](docs/ExecutionsApi.md#set_labels_on_terminated_executions_by_query) | **POST** /api/v1/{tenant}/executions/labels/by-query | Set label on executions filter by query parameters
*ExecutionsApi* | [**trigger_execution_by_get_webhook**](docs/ExecutionsApi.md#trigger_execution_by_get_webhook) | **GET** /api/v1/{tenant}/executions/webhook/{namespace}/{id}/{key} | Trigger a new execution by GET webhook trigger
*ExecutionsApi* | [**unqueue_execution**](docs/ExecutionsApi.md#unqueue_execution) | **POST** /api/v1/{tenant}/executions/{executionId}/unqueue | Unqueue an execution
*ExecutionsApi* | [**unqueue_executions_by_ids**](docs/ExecutionsApi.md#unqueue_executions_by_ids) | **POST** /api/v1/{tenant}/executions/unqueue/by-ids | Unqueue a list of executions
*ExecutionsApi* | [**unqueue_executions_by_query**](docs/ExecutionsApi.md#unqueue_executions_by_query) | **POST** /api/v1/{tenant}/executions/unqueue/by-query | Unqueue executions filter by query parameters
*ExecutionsApi* | [**update_execution_status**](docs/ExecutionsApi.md#update_execution_status) | **POST** /api/v1/{tenant}/executions/{executionId}/change-status | Change the state of an execution
*ExecutionsApi* | [**update_executions_status_by_ids**](docs/ExecutionsApi.md#update_executions_status_by_ids) | **POST** /api/v1/{tenant}/executions/change-status/by-ids | Change executions state by id
*ExecutionsApi* | [**update_executions_status_by_query**](docs/ExecutionsApi.md#update_executions_status_by_query) | **POST** /api/v1/{tenant}/executions/change-status/by-query | Change executions state by query parameters
*ExecutionsApi* | [**update_task_run_state**](docs/ExecutionsApi.md#update_task_run_state) | **POST** /api/v1/{tenant}/executions/{executionId}/state | Change state for a taskrun in an execution
*FlowsApi* | [**bulk_update_flows**](docs/FlowsApi.md#bulk_update_flows) | **POST** /api/v1/{tenant}/flows/bulk | Update from multiples yaml sources
*FlowsApi* | [**create_flow**](docs/FlowsApi.md#create_flow) | **POST** /api/v1/{tenant}/flows | Create a flow from yaml source
*FlowsApi* | [**delete_flow**](docs/FlowsApi.md#delete_flow) | **DELETE** /api/v1/{tenant}/flows/{namespace}/{id} | Delete a flow
*FlowsApi* | [**delete_flows_by_ids**](docs/FlowsApi.md#delete_flows_by_ids) | **DELETE** /api/v1/{tenant}/flows/delete/by-ids | Delete flows by their IDs.
*FlowsApi* | [**delete_flows_by_query**](docs/FlowsApi.md#delete_flows_by_query) | **DELETE** /api/v1/{tenant}/flows/delete/by-query | Delete flows returned by the query parameters.
*FlowsApi* | [**disable_flows_by_ids**](docs/FlowsApi.md#disable_flows_by_ids) | **POST** /api/v1/{tenant}/flows/disable/by-ids | Disable flows by their IDs.
*FlowsApi* | [**disable_flows_by_query**](docs/FlowsApi.md#disable_flows_by_query) | **POST** /api/v1/{tenant}/flows/disable/by-query | Disable flows returned by the query parameters.
*FlowsApi* | [**enable_flows_by_ids**](docs/FlowsApi.md#enable_flows_by_ids) | **POST** /api/v1/{tenant}/flows/enable/by-ids | Enable flows by their IDs.
*FlowsApi* | [**enable_flows_by_query**](docs/FlowsApi.md#enable_flows_by_query) | **POST** /api/v1/{tenant}/flows/enable/by-query | Enable flows returned by the query parameters.
*FlowsApi* | [**export_flows**](docs/FlowsApi.md#export_flows) | **GET** /api/v1/{tenant}/flows/export/by-query/csv | Export all flows as a streamed CSV file
*FlowsApi* | [**export_flows_by_ids**](docs/FlowsApi.md#export_flows_by_ids) | **POST** /api/v1/{tenant}/flows/export/by-ids | Export flows as a ZIP archive of yaml sources.
*FlowsApi* | [**export_flows_by_query**](docs/FlowsApi.md#export_flows_by_query) | **GET** /api/v1/{tenant}/flows/export/by-query | Export flows as a ZIP archive of yaml sources.
*FlowsApi* | [**flow**](docs/FlowsApi.md#flow) | **GET** /api/v1/{tenant}/flows/{namespace}/{id} | Get a flow
*FlowsApi* | [**flow_dependencies**](docs/FlowsApi.md#flow_dependencies) | **GET** /api/v1/{tenant}/flows/{namespace}/{id}/dependencies | Get flow dependencies
*FlowsApi* | [**flow_dependencies_from_namespace**](docs/FlowsApi.md#flow_dependencies_from_namespace) | **GET** /api/v1/{tenant}/namespaces/{namespace}/dependencies | Retrieve flow dependencies
*FlowsApi* | [**generate_flow_graph**](docs/FlowsApi.md#generate_flow_graph) | **GET** /api/v1/{tenant}/flows/{namespace}/{id}/graph | Generate a graph for a flow
*FlowsApi* | [**generate_flow_graph_from_source**](docs/FlowsApi.md#generate_flow_graph_from_source) | **POST** /api/v1/{tenant}/flows/graph | Generate a graph for a flow source
*FlowsApi* | [**import_flows**](docs/FlowsApi.md#import_flows) | **POST** /api/v1/{tenant}/flows/import |     Import flows as a ZIP archive of yaml sources or a multi-objects YAML file.     When sending a Yaml that contains one or more flows, a list of index is returned.     When sending a ZIP archive, a list of files that couldn&#39;t be imported is returned. 
*FlowsApi* | [**list_distinct_namespaces**](docs/FlowsApi.md#list_distinct_namespaces) | **GET** /api/v1/{tenant}/flows/distinct-namespaces | List all distinct namespaces
*FlowsApi* | [**list_flow_revisions**](docs/FlowsApi.md#list_flow_revisions) | **GET** /api/v1/{tenant}/flows/{namespace}/{id}/revisions | Get revisions for a flow
*FlowsApi* | [**list_flows_by_namespace**](docs/FlowsApi.md#list_flows_by_namespace) | **GET** /api/v1/{tenant}/flows/{namespace} | Retrieve all flows from a given namespace
*FlowsApi* | [**search_concurrency_limits**](docs/FlowsApi.md#search_concurrency_limits) | **GET** /api/v1/{tenant}/concurrency-limit/search | Search for flow concurrency limits
*FlowsApi* | [**search_flows**](docs/FlowsApi.md#search_flows) | **GET** /api/v1/{tenant}/flows/search | Search for flows
*FlowsApi* | [**search_flows_by_source_code**](docs/FlowsApi.md#search_flows_by_source_code) | **GET** /api/v1/{tenant}/flows/source | Search for flows source code
*FlowsApi* | [**task_from_flow**](docs/FlowsApi.md#task_from_flow) | **GET** /api/v1/{tenant}/flows/{namespace}/{id}/tasks/{taskId} | Get a flow task
*FlowsApi* | [**update_concurrency_limit**](docs/FlowsApi.md#update_concurrency_limit) | **PUT** /api/v1/{tenant}/concurrency-limit/{namespace}/{flowId} | Update a flow concurrency limit
*FlowsApi* | [**update_flow**](docs/FlowsApi.md#update_flow) | **PUT** /api/v1/{tenant}/flows/{namespace}/{id} | Update a flow
*FlowsApi* | [**update_flows_in_namespace**](docs/FlowsApi.md#update_flows_in_namespace) | **POST** /api/v1/{tenant}/flows/{namespace} | Update a complete namespace from yaml source
*FlowsApi* | [**update_task**](docs/FlowsApi.md#update_task) | **PATCH** /api/v1/{tenant}/flows/{namespace}/{id}/{taskId} | Update a single task on a flow
*FlowsApi* | [**validate_flows**](docs/FlowsApi.md#validate_flows) | **POST** /api/v1/{tenant}/flows/validate | Validate a list of flows
*FlowsApi* | [**validate_task**](docs/FlowsApi.md#validate_task) | **POST** /api/v1/{tenant}/flows/validate/task | Validate a task
*FlowsApi* | [**validate_trigger**](docs/FlowsApi.md#validate_trigger) | **POST** /api/v1/{tenant}/flows/validate/trigger | Validate trigger
*GroupsApi* | [**add_user_to_group**](docs/GroupsApi.md#add_user_to_group) | **PUT** /api/v1/{tenant}/groups/{id}/members/{userId} | Add a user to a group
*GroupsApi* | [**autocomplete_groups**](docs/GroupsApi.md#autocomplete_groups) | **POST** /api/v1/{tenant}/groups/autocomplete | List groups for autocomplete
*GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group) | **POST** /api/v1/{tenant}/groups | Create a group
*GroupsApi* | [**delete_group**](docs/GroupsApi.md#delete_group) | **DELETE** /api/v1/{tenant}/groups/{id} | Delete a group
*GroupsApi* | [**delete_user_from_group**](docs/GroupsApi.md#delete_user_from_group) | **DELETE** /api/v1/{tenant}/groups/{id}/members/{userId} | Remove a user from a group
*GroupsApi* | [**group**](docs/GroupsApi.md#group) | **GET** /api/v1/{tenant}/groups/{id} | Retrieve a group
*GroupsApi* | [**list_group_ids**](docs/GroupsApi.md#list_group_ids) | **POST** /api/v1/{tenant}/groups/ids | List groups by ids
*GroupsApi* | [**search_group_members**](docs/GroupsApi.md#search_group_members) | **GET** /api/v1/{tenant}/groups/{id}/members | Search for users in a group
*GroupsApi* | [**search_groups**](docs/GroupsApi.md#search_groups) | **GET** /api/v1/{tenant}/groups/search | Search for groups
*GroupsApi* | [**set_user_membership_for_group**](docs/GroupsApi.md#set_user_membership_for_group) | **PUT** /api/v1/{tenant}/groups/{id}/members/membership/{userId} | Update a user&#39;s membership type in a group
*GroupsApi* | [**update_group**](docs/GroupsApi.md#update_group) | **PUT** /api/v1/{tenant}/groups/{id} | Update a group
*KVApi* | [**delete_key_value**](docs/KVApi.md#delete_key_value) | **DELETE** /api/v1/{tenant}/namespaces/{namespace}/kv/{key} | Delete a key-value pair
*KVApi* | [**delete_key_values**](docs/KVApi.md#delete_key_values) | **DELETE** /api/v1/{tenant}/namespaces/{namespace}/kv | Bulk-delete multiple key/value pairs from the given namespace.
*KVApi* | [**key_value**](docs/KVApi.md#key_value) | **GET** /api/v1/{tenant}/namespaces/{namespace}/kv/{key} | Get value for a key
*KVApi* | [**list_all_keys**](docs/KVApi.md#list_all_keys) | **GET** /api/v1/{tenant}/kv | List all keys
*KVApi* | [**list_keys**](docs/KVApi.md#list_keys) | **GET** /api/v1/{tenant}/namespaces/{namespace}/kv | List all keys for a namespace
*KVApi* | [**list_keys_with_inheritence**](docs/KVApi.md#list_keys_with_inheritence) | **GET** /api/v1/{tenant}/namespaces/{namespace}/kv/inheritance | List all keys for inherited namespaces
*KVApi* | [**set_key_value**](docs/KVApi.md#set_key_value) | **PUT** /api/v1/{tenant}/namespaces/{namespace}/kv/{key} | Puts a key-value pair in store
*NamespacesApi* | [**autocomplete_namespaces**](docs/NamespacesApi.md#autocomplete_namespaces) | **POST** /api/v1/{tenant}/namespaces/autocomplete | List namespaces for autocomplete
*NamespacesApi* | [**create_namespace**](docs/NamespacesApi.md#create_namespace) | **POST** /api/v1/{tenant}/namespaces | Create a namespace
*NamespacesApi* | [**delete_namespace**](docs/NamespacesApi.md#delete_namespace) | **DELETE** /api/v1/{tenant}/namespaces/{id} | Delete a namespace
*NamespacesApi* | [**delete_secret**](docs/NamespacesApi.md#delete_secret) | **DELETE** /api/v1/{tenant}/namespaces/{namespace}/secrets/{key} | Delete a secret for a namespace
*NamespacesApi* | [**inherited_plugin_defaults**](docs/NamespacesApi.md#inherited_plugin_defaults) | **GET** /api/v1/{tenant}/namespaces/{id}/inherited-plugindefaults | List inherited plugin defaults
*NamespacesApi* | [**inherited_secrets**](docs/NamespacesApi.md#inherited_secrets) | **GET** /api/v1/{tenant}/namespaces/{namespace}/inherited-secrets | List inherited secrets
*NamespacesApi* | [**inherited_variables**](docs/NamespacesApi.md#inherited_variables) | **GET** /api/v1/{tenant}/namespaces/{id}/inherited-variables | List inherited variables
*NamespacesApi* | [**list_namespace_secrets**](docs/NamespacesApi.md#list_namespace_secrets) | **GET** /api/v1/{tenant}/namespaces/{namespace}/secrets | Get secrets for a namespace
*NamespacesApi* | [**namespace**](docs/NamespacesApi.md#namespace) | **GET** /api/v1/{tenant}/namespaces/{id} | Get a namespace
*NamespacesApi* | [**patch_secret**](docs/NamespacesApi.md#patch_secret) | **PATCH** /api/v1/{tenant}/namespaces/{namespace}/secrets/{key} | Patch a secret metadata for a namespace
*NamespacesApi* | [**put_secrets**](docs/NamespacesApi.md#put_secrets) | **PUT** /api/v1/{tenant}/namespaces/{namespace}/secrets | Update secrets for a namespace
*NamespacesApi* | [**search_namespaces**](docs/NamespacesApi.md#search_namespaces) | **GET** /api/v1/{tenant}/namespaces/search | Search for namespaces
*NamespacesApi* | [**update_namespace**](docs/NamespacesApi.md#update_namespace) | **PUT** /api/v1/{tenant}/namespaces/{id} | Update a namespace
*RolesApi* | [**autocomplete_roles**](docs/RolesApi.md#autocomplete_roles) | **POST** /api/v1/{tenant}/roles/autocomplete | List roles for autocomplete
*RolesApi* | [**create_role**](docs/RolesApi.md#create_role) | **POST** /api/v1/{tenant}/roles | Create a role
*RolesApi* | [**delete_role**](docs/RolesApi.md#delete_role) | **DELETE** /api/v1/{tenant}/roles/{id} | Delete a role
*RolesApi* | [**list_roles_from_given_ids**](docs/RolesApi.md#list_roles_from_given_ids) | **POST** /api/v1/{tenant}/roles/ids | List roles by ids
*RolesApi* | [**role**](docs/RolesApi.md#role) | **GET** /api/v1/{tenant}/roles/{id} | Retrieve a role
*RolesApi* | [**search_roles**](docs/RolesApi.md#search_roles) | **GET** /api/v1/{tenant}/roles/search | Search for roles
*RolesApi* | [**update_role**](docs/RolesApi.md#update_role) | **PUT** /api/v1/{tenant}/roles/{id} | Update a role
*ServiceAccountApi* | [**create_api_tokens_for_service_account**](docs/ServiceAccountApi.md#create_api_tokens_for_service_account) | **POST** /api/v1/service-accounts/{id}/api-tokens | Create new API Token for a specific service account
*ServiceAccountApi* | [**create_api_tokens_for_service_account_with_tenant**](docs/ServiceAccountApi.md#create_api_tokens_for_service_account_with_tenant) | **POST** /api/v1/{tenant}/service-accounts/{id}/api-tokens | Create new API Token for a specific service account
*ServiceAccountApi* | [**create_service_account**](docs/ServiceAccountApi.md#create_service_account) | **POST** /api/v1/service-accounts | Create a service account
*ServiceAccountApi* | [**create_service_account_for_tenant**](docs/ServiceAccountApi.md#create_service_account_for_tenant) | **POST** /api/v1/{tenant}/service-accounts | Create a service account for the given tenant
*ServiceAccountApi* | [**delete_api_token_for_service_account**](docs/ServiceAccountApi.md#delete_api_token_for_service_account) | **DELETE** /api/v1/service-accounts/{id}/api-tokens/{tokenId} | Delete an API Token for specific service account and token id
*ServiceAccountApi* | [**delete_api_token_for_service_account_with_tenant**](docs/ServiceAccountApi.md#delete_api_token_for_service_account_with_tenant) | **DELETE** /api/v1/{tenant}/service-accounts/{id}/api-tokens/{tokenId} | Delete an API Token for specific service account and token id
*ServiceAccountApi* | [**delete_service_account**](docs/ServiceAccountApi.md#delete_service_account) | **DELETE** /api/v1/service-accounts/{id} | Delete a service account
*ServiceAccountApi* | [**delete_service_account_for_tenant**](docs/ServiceAccountApi.md#delete_service_account_for_tenant) | **DELETE** /api/v1/{tenant}/service-accounts/{id} | Delete a service account
*ServiceAccountApi* | [**list_api_tokens_for_service_account**](docs/ServiceAccountApi.md#list_api_tokens_for_service_account) | **GET** /api/v1/service-accounts/{id}/api-tokens | List API tokens for a specific service account
*ServiceAccountApi* | [**list_api_tokens_for_service_account_with_tenant**](docs/ServiceAccountApi.md#list_api_tokens_for_service_account_with_tenant) | **GET** /api/v1/{tenant}/service-accounts/{id}/api-tokens | List API tokens for a specific service account
*ServiceAccountApi* | [**list_service_accounts**](docs/ServiceAccountApi.md#list_service_accounts) | **GET** /api/v1/service-accounts | List service accounts. Superadmin-only. 
*ServiceAccountApi* | [**patch_service_account_details**](docs/ServiceAccountApi.md#patch_service_account_details) | **PATCH** /api/v1/service-accounts/{id} | Update service account details
*ServiceAccountApi* | [**patch_service_account_super_admin**](docs/ServiceAccountApi.md#patch_service_account_super_admin) | **PATCH** /api/v1/service-accounts/{id}/superadmin | Update service account superadmin privileges
*ServiceAccountApi* | [**service_account**](docs/ServiceAccountApi.md#service_account) | **GET** /api/v1/service-accounts/{id} | Get a service account
*ServiceAccountApi* | [**service_account_for_tenant**](docs/ServiceAccountApi.md#service_account_for_tenant) | **GET** /api/v1/{tenant}/service-accounts/{id} | Retrieve a service account
*ServiceAccountApi* | [**update_service_account**](docs/ServiceAccountApi.md#update_service_account) | **PUT** /api/v1/{tenant}/service-accounts/{id} | Update a user service account
*TriggersApi* | [**delete_backfill**](docs/TriggersApi.md#delete_backfill) | **POST** /api/v1/{tenant}/triggers/backfill/delete | Delete a backfill
*TriggersApi* | [**delete_backfill_by_ids**](docs/TriggersApi.md#delete_backfill_by_ids) | **POST** /api/v1/{tenant}/triggers/backfill/delete/by-triggers | Delete backfill for given triggers
*TriggersApi* | [**delete_backfill_by_query**](docs/TriggersApi.md#delete_backfill_by_query) | **POST** /api/v1/{tenant}/triggers/backfill/delete/by-query | Delete backfill for given triggers
*TriggersApi* | [**delete_trigger**](docs/TriggersApi.md#delete_trigger) | **DELETE** /api/v1/{tenant}/triggers/{namespace}/{flowId}/{triggerId} | Delete a trigger
*TriggersApi* | [**delete_triggers_by_ids**](docs/TriggersApi.md#delete_triggers_by_ids) | **DELETE** /api/v1/{tenant}/triggers/delete/by-triggers | Delete given triggers
*TriggersApi* | [**delete_triggers_by_query**](docs/TriggersApi.md#delete_triggers_by_query) | **DELETE** /api/v1/{tenant}/triggers/delete/by-query | Delete triggers by query parameters
*TriggersApi* | [**disabled_triggers_by_ids**](docs/TriggersApi.md#disabled_triggers_by_ids) | **POST** /api/v1/{tenant}/triggers/set-disabled/by-triggers | Disable/enable given triggers
*TriggersApi* | [**disabled_triggers_by_query**](docs/TriggersApi.md#disabled_triggers_by_query) | **POST** /api/v1/{tenant}/triggers/set-disabled/by-query | Disable/enable triggers by query parameters
*TriggersApi* | [**export_triggers**](docs/TriggersApi.md#export_triggers) | **GET** /api/v1/{tenant}/triggers/export/by-query/csv | Export all triggers as a streamed CSV file
*TriggersApi* | [**pause_backfill**](docs/TriggersApi.md#pause_backfill) | **PUT** /api/v1/{tenant}/triggers/backfill/pause | Pause a backfill
*TriggersApi* | [**pause_backfill_by_ids**](docs/TriggersApi.md#pause_backfill_by_ids) | **POST** /api/v1/{tenant}/triggers/backfill/pause/by-triggers | Pause backfill for given triggers
*TriggersApi* | [**pause_backfill_by_query**](docs/TriggersApi.md#pause_backfill_by_query) | **POST** /api/v1/{tenant}/triggers/backfill/pause/by-query | Pause backfill for given triggers
*TriggersApi* | [**restart_trigger**](docs/TriggersApi.md#restart_trigger) | **POST** /api/v1/{tenant}/triggers/{namespace}/{flowId}/{triggerId}/restart | Restart a trigger
*TriggersApi* | [**search_triggers**](docs/TriggersApi.md#search_triggers) | **GET** /api/v1/{tenant}/triggers/search | Search for triggers
*TriggersApi* | [**search_triggers_for_flow**](docs/TriggersApi.md#search_triggers_for_flow) | **GET** /api/v1/{tenant}/triggers/{namespace}/{flowId} | Get all triggers for a flow
*TriggersApi* | [**unlock_trigger**](docs/TriggersApi.md#unlock_trigger) | **POST** /api/v1/{tenant}/triggers/{namespace}/{flowId}/{triggerId}/unlock | Unlock a trigger
*TriggersApi* | [**unlock_triggers_by_ids**](docs/TriggersApi.md#unlock_triggers_by_ids) | **POST** /api/v1/{tenant}/triggers/unlock/by-triggers | Unlock given triggers
*TriggersApi* | [**unlock_triggers_by_query**](docs/TriggersApi.md#unlock_triggers_by_query) | **POST** /api/v1/{tenant}/triggers/unlock/by-query | Unlock triggers by query parameters
*TriggersApi* | [**unpause_backfill**](docs/TriggersApi.md#unpause_backfill) | **PUT** /api/v1/{tenant}/triggers/backfill/unpause | Unpause a backfill
*TriggersApi* | [**unpause_backfill_by_ids**](docs/TriggersApi.md#unpause_backfill_by_ids) | **POST** /api/v1/{tenant}/triggers/backfill/unpause/by-triggers | Unpause backfill for given triggers
*TriggersApi* | [**unpause_backfill_by_query**](docs/TriggersApi.md#unpause_backfill_by_query) | **POST** /api/v1/{tenant}/triggers/backfill/unpause/by-query | Unpause backfill for given triggers
*TriggersApi* | [**update_trigger**](docs/TriggersApi.md#update_trigger) | **PUT** /api/v1/{tenant}/triggers | Update a trigger
*UsersApi* | [**autocomplete_users**](docs/UsersApi.md#autocomplete_users) | **POST** /api/v1/{tenant}/tenant-access/autocomplete | List users for autocomplete
*UsersApi* | [**create_api_tokens_for_user**](docs/UsersApi.md#create_api_tokens_for_user) | **POST** /api/v1/users/{id}/api-tokens | Create new API Token for a specific user
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /api/v1/users | Create a new user account
*UsersApi* | [**delete_api_token_for_user**](docs/UsersApi.md#delete_api_token_for_user) | **DELETE** /api/v1/users/{id}/api-tokens/{tokenId} | Delete an API Token for specific user and token id
*UsersApi* | [**delete_refresh_token**](docs/UsersApi.md#delete_refresh_token) | **DELETE** /api/v1/users/{id}/refresh-token | Delete a user refresh token
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /api/v1/users/{id} | Delete a user
*UsersApi* | [**delete_user_auth_method**](docs/UsersApi.md#delete_user_auth_method) | **DELETE** /api/v1/users/{id}/auths/{auth} | Update user password
*UsersApi* | [**impersonate**](docs/UsersApi.md#impersonate) | **POST** /api/v1/users/{id}/impersonate | Impersonate a user
*UsersApi* | [**list_api_tokens_for_user**](docs/UsersApi.md#list_api_tokens_for_user) | **GET** /api/v1/users/{id}/api-tokens | List API tokens for a specific user
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /api/v1/users | Retrieve users
*UsersApi* | [**patch_user**](docs/UsersApi.md#patch_user) | **PATCH** /api/v1/users/{id} | Update user details
*UsersApi* | [**patch_user_demo**](docs/UsersApi.md#patch_user_demo) | **PATCH** /api/v1/users/{id}/restricted | Update user demo
*UsersApi* | [**patch_user_password**](docs/UsersApi.md#patch_user_password) | **PATCH** /api/v1/users/{id}/password | Update user password
*UsersApi* | [**patch_user_super_admin**](docs/UsersApi.md#patch_user_super_admin) | **PATCH** /api/v1/users/{id}/superadmin | Update user superadmin privileges
*UsersApi* | [**update_current_user_password**](docs/UsersApi.md#update_current_user_password) | **PUT** /api/v1/me/password | Update authenticated user password
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /api/v1/users/{id} | Update a user account
*UsersApi* | [**update_user_groups**](docs/UsersApi.md#update_user_groups) | **PUT** /api/v1/{tenant}/users/{id}/groups | Update the list of groups a user belongs to for the given tenant
*UsersApi* | [**user**](docs/UsersApi.md#user) | **GET** /api/v1/users/{id} | Get a user


## Documentation For Models

 - [AbstractFlow](docs/AbstractFlow.md)
 - [AbstractGraph](docs/AbstractGraph.md)
 - [AbstractGraphBranchType](docs/AbstractGraphBranchType.md)
 - [AbstractMetricEntryObject](docs/AbstractMetricEntryObject.md)
 - [AbstractTrigger](docs/AbstractTrigger.md)
 - [AbstractTriggerForExecution](docs/AbstractTriggerForExecution.md)
 - [AbstractUser](docs/AbstractUser.md)
 - [AbstractUserTenantIdentityProvider](docs/AbstractUserTenantIdentityProvider.md)
 - [Action](docs/Action.md)
 - [ApiAuth](docs/ApiAuth.md)
 - [ApiAutocomplete](docs/ApiAutocomplete.md)
 - [ApiGroupSummary](docs/ApiGroupSummary.md)
 - [ApiIds](docs/ApiIds.md)
 - [ApiPatchSuperAdminRequest](docs/ApiPatchSuperAdminRequest.md)
 - [ApiRoleSummary](docs/ApiRoleSummary.md)
 - [ApiSecretListResponseApiSecretMeta](docs/ApiSecretListResponseApiSecretMeta.md)
 - [ApiSecretMeta](docs/ApiSecretMeta.md)
 - [ApiSecretMetaEE](docs/ApiSecretMetaEE.md)
 - [ApiSecretTag](docs/ApiSecretTag.md)
 - [ApiSecretValue](docs/ApiSecretValue.md)
 - [ApiTenant](docs/ApiTenant.md)
 - [ApiTenantSummary](docs/ApiTenantSummary.md)
 - [ApiToken](docs/ApiToken.md)
 - [ApiTokenList](docs/ApiTokenList.md)
 - [ApiUser](docs/ApiUser.md)
 - [AppResponse](docs/AppResponse.md)
 - [AppResponseUILayout](docs/AppResponseUILayout.md)
 - [AppsControllerApiApp](docs/AppsControllerApiApp.md)
 - [AppsControllerApiAppCatalogItem](docs/AppsControllerApiAppCatalogItem.md)
 - [AppsControllerApiAppSource](docs/AppsControllerApiAppSource.md)
 - [AppsControllerApiAppTags](docs/AppsControllerApiAppTags.md)
 - [AppsControllerApiBulkImportResponse](docs/AppsControllerApiBulkImportResponse.md)
 - [AppsControllerApiBulkImportResponseError](docs/AppsControllerApiBulkImportResponseError.md)
 - [AppsControllerApiBulkOperationRequest](docs/AppsControllerApiBulkOperationRequest.md)
 - [Assertion](docs/Assertion.md)
 - [AssertionResult](docs/AssertionResult.md)
 - [AssertionRunError](docs/AssertionRunError.md)
 - [Asset](docs/Asset.md)
 - [AssetIdentifier](docs/AssetIdentifier.md)
 - [AssetTopologyGraph](docs/AssetTopologyGraph.md)
 - [AssetTopologyGraphEdge](docs/AssetTopologyGraphEdge.md)
 - [AssetTopologyGraphNode](docs/AssetTopologyGraphNode.md)
 - [AssetTopologyGraphNodeNodeType](docs/AssetTopologyGraphNodeNodeType.md)
 - [AssetsControllerApiAsset](docs/AssetsControllerApiAsset.md)
 - [AssetsControllerApiAssetUsage](docs/AssetsControllerApiAssetUsage.md)
 - [AssetsDeclaration](docs/AssetsDeclaration.md)
 - [AssetsInOut](docs/AssetsInOut.md)
 - [AttributeReference](docs/AttributeReference.md)
 - [AuditLog](docs/AuditLog.md)
 - [AuditLogControllerApiAuditLogItem](docs/AuditLogControllerApiAuditLogItem.md)
 - [AuditLogControllerAuditLogDiff](docs/AuditLogControllerAuditLogDiff.md)
 - [AuditLogControllerAuditLogOption](docs/AuditLogControllerAuditLogOption.md)
 - [AuditLogControllerFindRequest](docs/AuditLogControllerFindRequest.md)
 - [AuditLogDetail](docs/AuditLogDetail.md)
 - [AuthControllerAuth](docs/AuthControllerAuth.md)
 - [AuthControllerInvitationUserRequest](docs/AuthControllerInvitationUserRequest.md)
 - [AuthControllerResetPasswordRequest](docs/AuthControllerResetPasswordRequest.md)
 - [Backfill](docs/Backfill.md)
 - [Banner](docs/Banner.md)
 - [BannerType](docs/BannerType.md)
 - [BaseAuditLog](docs/BaseAuditLog.md)
 - [BaseResourcePatchRequest](docs/BaseResourcePatchRequest.md)
 - [BaseResourceScimResource](docs/BaseResourceScimResource.md)
 - [BaseResourceSearchRequest](docs/BaseResourceSearchRequest.md)
 - [BasicAuthCredentials](docs/BasicAuthCredentials.md)
 - [Binding](docs/Binding.md)
 - [BindingType](docs/BindingType.md)
 - [Blueprint](docs/Blueprint.md)
 - [BlueprintControllerApiBlueprintItem](docs/BlueprintControllerApiBlueprintItem.md)
 - [BlueprintControllerApiBlueprintItemWithSource](docs/BlueprintControllerApiBlueprintItemWithSource.md)
 - [BlueprintControllerApiBlueprintTagItem](docs/BlueprintControllerApiBlueprintTagItem.md)
 - [BlueprintControllerApiFlowBlueprint](docs/BlueprintControllerApiFlowBlueprint.md)
 - [BlueprintControllerFlowBlueprintCreateOrUpdate](docs/BlueprintControllerFlowBlueprintCreateOrUpdate.md)
 - [BlueprintControllerKind](docs/BlueprintControllerKind.md)
 - [BlueprintControllerUseBlueprintTemplateRequest](docs/BlueprintControllerUseBlueprintTemplateRequest.md)
 - [BlueprintControllerUseBlueprintTemplateResponse](docs/BlueprintControllerUseBlueprintTemplateResponse.md)
 - [BlueprintTemplate](docs/BlueprintTemplate.md)
 - [BlueprintWithFlowEntity](docs/BlueprintWithFlowEntity.md)
 - [Breakpoint](docs/Breakpoint.md)
 - [BulkErrorResponse](docs/BulkErrorResponse.md)
 - [BulkImportAppsRequest](docs/BulkImportAppsRequest.md)
 - [BulkResponse](docs/BulkResponse.md)
 - [Cache](docs/Cache.md)
 - [ChartChartOption](docs/ChartChartOption.md)
 - [ChartFiltersOverrides](docs/ChartFiltersOverrides.md)
 - [Check](docs/Check.md)
 - [CheckBehavior](docs/CheckBehavior.md)
 - [CheckStyle](docs/CheckStyle.md)
 - [Concurrency](docs/Concurrency.md)
 - [ConcurrencyBehavior](docs/ConcurrencyBehavior.md)
 - [ConcurrencyLimit](docs/ConcurrencyLimit.md)
 - [Condition](docs/Condition.md)
 - [ConversionServiceProvider](docs/ConversionServiceProvider.md)
 - [ConvertibleMultiValuesString](docs/ConvertibleMultiValuesString.md)
 - [ConvertibleValuesListString](docs/ConvertibleValuesListString.md)
 - [CreateApiTokenRequest](docs/CreateApiTokenRequest.md)
 - [CreateApiTokenResponse](docs/CreateApiTokenResponse.md)
 - [CreateNamespaceFileRequest](docs/CreateNamespaceFileRequest.md)
 - [CreateSecurityIntegrationRequest](docs/CreateSecurityIntegrationRequest.md)
 - [CrudEventType](docs/CrudEventType.md)
 - [DailyExecutionStatistics](docs/DailyExecutionStatistics.md)
 - [DailyExecutionStatisticsDuration](docs/DailyExecutionStatisticsDuration.md)
 - [DailyExecutionStatisticsExecutionCounts](docs/DailyExecutionStatisticsExecutionCounts.md)
 - [Dashboard](docs/Dashboard.md)
 - [DashboardControllerPreviewRequest](docs/DashboardControllerPreviewRequest.md)
 - [DeleteTriggersByQueryRequest](docs/DeleteTriggersByQueryRequest.md)
 - [DeletedInterface](docs/DeletedInterface.md)
 - [DependsOn](docs/DependsOn.md)
 - [DocumentationWithSchema](docs/DocumentationWithSchema.md)
 - [EditionProviderEdition](docs/EditionProviderEdition.md)
 - [Email](docs/Email.md)
 - [EventAppResponse](docs/EventAppResponse.md)
 - [EventExecution](docs/EventExecution.md)
 - [EventExecutionStatusEvent](docs/EventExecutionStatusEvent.md)
 - [EventLogEntry](docs/EventLogEntry.md)
 - [ExecutableTaskSubflowId](docs/ExecutableTaskSubflowId.md)
 - [Execution](docs/Execution.md)
 - [ExecutionControllerApiValidateExecutionInputsResponse](docs/ExecutionControllerApiValidateExecutionInputsResponse.md)
 - [ExecutionControllerApiValidateExecutionInputsResponseApiCheckFailure](docs/ExecutionControllerApiValidateExecutionInputsResponseApiCheckFailure.md)
 - [ExecutionControllerApiValidateExecutionInputsResponseApiInputAndValue](docs/ExecutionControllerApiValidateExecutionInputsResponseApiInputAndValue.md)
 - [ExecutionControllerApiValidateExecutionInputsResponseApiInputError](docs/ExecutionControllerApiValidateExecutionInputsResponseApiInputError.md)
 - [ExecutionControllerEvalResult](docs/ExecutionControllerEvalResult.md)
 - [ExecutionControllerExecutionResponse](docs/ExecutionControllerExecutionResponse.md)
 - [ExecutionControllerLastExecutionResponse](docs/ExecutionControllerLastExecutionResponse.md)
 - [ExecutionControllerSetLabelsByIdsRequest](docs/ExecutionControllerSetLabelsByIdsRequest.md)
 - [ExecutionControllerStateRequest](docs/ExecutionControllerStateRequest.md)
 - [ExecutionControllerWebhookResponse](docs/ExecutionControllerWebhookResponse.md)
 - [ExecutionKind](docs/ExecutionKind.md)
 - [ExecutionMetadata](docs/ExecutionMetadata.md)
 - [ExecutionRepositoryInterfaceChildFilter](docs/ExecutionRepositoryInterfaceChildFilter.md)
 - [ExecutionRepositoryInterfaceFlowFilter](docs/ExecutionRepositoryInterfaceFlowFilter.md)
 - [ExecutionStatusEvent](docs/ExecutionStatusEvent.md)
 - [ExecutionTrigger](docs/ExecutionTrigger.md)
 - [ExecutionUsage](docs/ExecutionUsage.md)
 - [FileAttributes](docs/FileAttributes.md)
 - [FileAttributesFileType](docs/FileAttributesFileType.md)
 - [FileMetas](docs/FileMetas.md)
 - [Filter](docs/Filter.md)
 - [Fixtures](docs/Fixtures.md)
 - [Flow](docs/Flow.md)
 - [FlowControllerTaskValidationType](docs/FlowControllerTaskValidationType.md)
 - [FlowForExecution](docs/FlowForExecution.md)
 - [FlowGenerationPrompt](docs/FlowGenerationPrompt.md)
 - [FlowGraph](docs/FlowGraph.md)
 - [FlowGraphCluster](docs/FlowGraphCluster.md)
 - [FlowGraphEdge](docs/FlowGraphEdge.md)
 - [FlowId](docs/FlowId.md)
 - [FlowInterface](docs/FlowInterface.md)
 - [FlowNode](docs/FlowNode.md)
 - [FlowRelation](docs/FlowRelation.md)
 - [FlowScope](docs/FlowScope.md)
 - [FlowTopologyGraph](docs/FlowTopologyGraph.md)
 - [FlowTopologyGraphEdge](docs/FlowTopologyGraphEdge.md)
 - [FlowUsage](docs/FlowUsage.md)
 - [FlowWithSource](docs/FlowWithSource.md)
 - [GroupIdentifier](docs/GroupIdentifier.md)
 - [GroupIdentifierMembership](docs/GroupIdentifierMembership.md)
 - [GroupUsage](docs/GroupUsage.md)
 - [HttpParameters](docs/HttpParameters.md)
 - [IAMBindingControllerApiBindingDetail](docs/IAMBindingControllerApiBindingDetail.md)
 - [IAMBindingControllerApiBindingGroup](docs/IAMBindingControllerApiBindingGroup.md)
 - [IAMBindingControllerApiBindingUser](docs/IAMBindingControllerApiBindingUser.md)
 - [IAMBindingControllerApiCreateBindingRequest](docs/IAMBindingControllerApiCreateBindingRequest.md)
 - [IAMBindingControllerApiRole](docs/IAMBindingControllerApiRole.md)
 - [IAMGroupControllerApiCreateGroupRequest](docs/IAMGroupControllerApiCreateGroupRequest.md)
 - [IAMGroupControllerApiGroupDetail](docs/IAMGroupControllerApiGroupDetail.md)
 - [IAMGroupControllerApiGroupMember](docs/IAMGroupControllerApiGroupMember.md)
 - [IAMGroupControllerApiGroupMembership](docs/IAMGroupControllerApiGroupMembership.md)
 - [IAMGroupControllerApiUpdateGroupRequest](docs/IAMGroupControllerApiUpdateGroupRequest.md)
 - [IAMInvitationControllerApiInvitationCreateRequest](docs/IAMInvitationControllerApiInvitationCreateRequest.md)
 - [IAMInvitationControllerApiInvitationDetail](docs/IAMInvitationControllerApiInvitationDetail.md)
 - [IAMInvitationControllerApiInvitationRole](docs/IAMInvitationControllerApiInvitationRole.md)
 - [IAMRoleControllerApiRoleCreateOrUpdateRequest](docs/IAMRoleControllerApiRoleCreateOrUpdateRequest.md)
 - [IAMRoleControllerApiRoleCreateOrUpdateRequestPermissions](docs/IAMRoleControllerApiRoleCreateOrUpdateRequestPermissions.md)
 - [IAMRoleControllerApiRoleDetail](docs/IAMRoleControllerApiRoleDetail.md)
 - [IAMServiceAccountControllerApiCreateServiceAccountRequest](docs/IAMServiceAccountControllerApiCreateServiceAccountRequest.md)
 - [IAMServiceAccountControllerApiGroup](docs/IAMServiceAccountControllerApiGroup.md)
 - [IAMServiceAccountControllerApiPatchServiceAccountRequest](docs/IAMServiceAccountControllerApiPatchServiceAccountRequest.md)
 - [IAMServiceAccountControllerApiServiceAccountDetail](docs/IAMServiceAccountControllerApiServiceAccountDetail.md)
 - [IAMServiceAccountControllerApiServiceAccountRequest](docs/IAMServiceAccountControllerApiServiceAccountRequest.md)
 - [IAMServiceAccountControllerApiServiceAccountResponse](docs/IAMServiceAccountControllerApiServiceAccountResponse.md)
 - [IAMTenantAccessControllerApiAuthentication](docs/IAMTenantAccessControllerApiAuthentication.md)
 - [IAMTenantAccessControllerApiCreateTenantAccessRequest](docs/IAMTenantAccessControllerApiCreateTenantAccessRequest.md)
 - [IAMTenantAccessControllerApiGroup](docs/IAMTenantAccessControllerApiGroup.md)
 - [IAMTenantAccessControllerApiRoleAssignment](docs/IAMTenantAccessControllerApiRoleAssignment.md)
 - [IAMTenantAccessControllerApiTenantAccess](docs/IAMTenantAccessControllerApiTenantAccess.md)
 - [IAMTenantAccessControllerApiUserPermission](docs/IAMTenantAccessControllerApiUserPermission.md)
 - [IAMTenantAccessControllerApiUserTenantAccess](docs/IAMTenantAccessControllerApiUserTenantAccess.md)
 - [IAMTenantAccessControllerUserApiAutocomplete](docs/IAMTenantAccessControllerUserApiAutocomplete.md)
 - [IAMUserControllerApiCreateOrUpdateUserRequest](docs/IAMUserControllerApiCreateOrUpdateUserRequest.md)
 - [IAMUserControllerApiGroup](docs/IAMUserControllerApiGroup.md)
 - [IAMUserControllerApiPatchRestrictedRequest](docs/IAMUserControllerApiPatchRestrictedRequest.md)
 - [IAMUserControllerApiPatchUserPasswordRequest](docs/IAMUserControllerApiPatchUserPasswordRequest.md)
 - [IAMUserControllerApiUser](docs/IAMUserControllerApiUser.md)
 - [IAMUserControllerApiUserAuth](docs/IAMUserControllerApiUserAuth.md)
 - [IAMUserControllerApiUserSummary](docs/IAMUserControllerApiUserSummary.md)
 - [IAMUserGroupControllerApiUpdateUserGroupsRequest](docs/IAMUserGroupControllerApiUpdateUserGroupsRequest.md)
 - [IdWithNamespace](docs/IdWithNamespace.md)
 - [IdentityProvider](docs/IdentityProvider.md)
 - [InputObject](docs/InputObject.md)
 - [InputType](docs/InputType.md)
 - [InstanceControllerApiActiveService](docs/InstanceControllerApiActiveService.md)
 - [InstanceControllerApiActiveServiceList](docs/InstanceControllerApiActiveServiceList.md)
 - [InstanceControllerApiCreateOrUpdateWorkerGroupRequest](docs/InstanceControllerApiCreateOrUpdateWorkerGroupRequest.md)
 - [InstanceControllerApiPluginArtifact](docs/InstanceControllerApiPluginArtifact.md)
 - [InstanceControllerApiPluginArtifactListPluginArtifact](docs/InstanceControllerApiPluginArtifactListPluginArtifact.md)
 - [InstanceControllerApiPluginArtifactListPluginResolutionResult](docs/InstanceControllerApiPluginArtifactListPluginResolutionResult.md)
 - [InstanceControllerApiPluginListRequest](docs/InstanceControllerApiPluginListRequest.md)
 - [InstanceControllerApiPluginVersionDetails](docs/InstanceControllerApiPluginVersionDetails.md)
 - [InstanceControllerApiPluginVersionDetailsApiPluginClass](docs/InstanceControllerApiPluginVersionDetailsApiPluginClass.md)
 - [InstanceControllerApiPluginVersionDetailsApiPluginClasses](docs/InstanceControllerApiPluginVersionDetailsApiPluginClasses.md)
 - [InstanceControllerApiPluginVersions](docs/InstanceControllerApiPluginVersions.md)
 - [InstanceControllerApiPluginVersionsApiPluginVersionAndMetadata](docs/InstanceControllerApiPluginVersionsApiPluginVersionAndMetadata.md)
 - [InstanceControllerApiServerInstance](docs/InstanceControllerApiServerInstance.md)
 - [InstanceControllerApiServiceInstance](docs/InstanceControllerApiServiceInstance.md)
 - [InstanceControllerApiWorkerGroup](docs/InstanceControllerApiWorkerGroup.md)
 - [InstanceControllerApiWorkerGroupDetails](docs/InstanceControllerApiWorkerGroupDetails.md)
 - [InstanceControllerApiWorkerGroupItem](docs/InstanceControllerApiWorkerGroupItem.md)
 - [InstanceControllerApiWorkerGroupList](docs/InstanceControllerApiWorkerGroupList.md)
 - [Invitation](docs/Invitation.md)
 - [InvitationInvitationStatus](docs/InvitationInvitationStatus.md)
 - [Isolation](docs/Isolation.md)
 - [KVControllerApiDeleteBulkRequest](docs/KVControllerApiDeleteBulkRequest.md)
 - [KVControllerApiDeleteBulkResponse](docs/KVControllerApiDeleteBulkResponse.md)
 - [KVControllerTypedValue](docs/KVControllerTypedValue.md)
 - [KVEntry](docs/KVEntry.md)
 - [KVType](docs/KVType.md)
 - [Label](docs/Label.md)
 - [LeftSidebarConfiguration](docs/LeftSidebarConfiguration.md)
 - [Level](docs/Level.md)
 - [Listener](docs/Listener.md)
 - [LogEntry](docs/LogEntry.md)
 - [MapObjectObject](docs/MapObjectObject.md)
 - [MeControllerApiMe](docs/MeControllerApiMe.md)
 - [MeControllerApiProfile](docs/MeControllerApiProfile.md)
 - [MeControllerApiTenant](docs/MeControllerApiTenant.md)
 - [MeControllerApiUpdatePasswordRequest](docs/MeControllerApiUpdatePasswordRequest.md)
 - [MeControllerApiUserDetailsRequest](docs/MeControllerApiUserDetailsRequest.md)
 - [Meta](docs/Meta.md)
 - [Metric](docs/Metric.md)
 - [MetricAggregation](docs/MetricAggregation.md)
 - [MetricAggregations](docs/MetricAggregations.md)
 - [MetricEntry](docs/MetricEntry.md)
 - [MetricTag](docs/MetricTag.md)
 - [MiscControllerApiUsage](docs/MiscControllerApiUsage.md)
 - [MiscControllerConfiguration](docs/MiscControllerConfiguration.md)
 - [MiscControllerEEConfiguration](docs/MiscControllerEEConfiguration.md)
 - [MiscControllerEnvironment](docs/MiscControllerEnvironment.md)
 - [MiscControllerLicenseInfo](docs/MiscControllerLicenseInfo.md)
 - [MiscControllerPluginIdAndVersion](docs/MiscControllerPluginIdAndVersion.md)
 - [MiscControllerPreview](docs/MiscControllerPreview.md)
 - [MiscControllerTenantConfigurationInfo](docs/MiscControllerTenantConfigurationInfo.md)
 - [ModelSchema](docs/ModelSchema.md)
 - [Name](docs/Name.md)
 - [Namespace](docs/Namespace.md)
 - [NamespaceAllowedNamespace](docs/NamespaceAllowedNamespace.md)
 - [NamespaceAllowedTrigger](docs/NamespaceAllowedTrigger.md)
 - [NamespaceFileRevision](docs/NamespaceFileRevision.md)
 - [NamespaceLight](docs/NamespaceLight.md)
 - [Output](docs/Output.md)
 - [OutputValue](docs/OutputValue.md)
 - [PageRequest](docs/PageRequest.md)
 - [PagedResultsApiGroupSummary](docs/PagedResultsApiGroupSummary.md)
 - [PagedResultsApiRoleSummary](docs/PagedResultsApiRoleSummary.md)
 - [PagedResultsAppsControllerApiApp](docs/PagedResultsAppsControllerApiApp.md)
 - [PagedResultsAppsControllerApiAppCatalogItem](docs/PagedResultsAppsControllerApiAppCatalogItem.md)
 - [PagedResultsAssetsControllerApiAsset](docs/PagedResultsAssetsControllerApiAsset.md)
 - [PagedResultsAssetsControllerApiAssetUsage](docs/PagedResultsAssetsControllerApiAssetUsage.md)
 - [PagedResultsAuditLogControllerApiAuditLogItem](docs/PagedResultsAuditLogControllerApiAuditLogItem.md)
 - [PagedResultsBlueprint](docs/PagedResultsBlueprint.md)
 - [PagedResultsBlueprintControllerApiBlueprintItem](docs/PagedResultsBlueprintControllerApiBlueprintItem.md)
 - [PagedResultsConcurrencyLimit](docs/PagedResultsConcurrencyLimit.md)
 - [PagedResultsDashboard](docs/PagedResultsDashboard.md)
 - [PagedResultsExecution](docs/PagedResultsExecution.md)
 - [PagedResultsFlow](docs/PagedResultsFlow.md)
 - [PagedResultsIAMBindingControllerApiBindingDetail](docs/PagedResultsIAMBindingControllerApiBindingDetail.md)
 - [PagedResultsIAMGroupControllerApiGroupMember](docs/PagedResultsIAMGroupControllerApiGroupMember.md)
 - [PagedResultsIAMInvitationControllerApiInvitationDetail](docs/PagedResultsIAMInvitationControllerApiInvitationDetail.md)
 - [PagedResultsIAMServiceAccountControllerApiServiceAccountDetail](docs/PagedResultsIAMServiceAccountControllerApiServiceAccountDetail.md)
 - [PagedResultsIAMTenantAccessControllerApiUserTenantAccess](docs/PagedResultsIAMTenantAccessControllerApiUserTenantAccess.md)
 - [PagedResultsIAMUserControllerApiUserSummary](docs/PagedResultsIAMUserControllerApiUserSummary.md)
 - [PagedResultsInstanceControllerApiPluginArtifact](docs/PagedResultsInstanceControllerApiPluginArtifact.md)
 - [PagedResultsInstanceControllerApiServiceInstance](docs/PagedResultsInstanceControllerApiServiceInstance.md)
 - [PagedResultsKVEntry](docs/PagedResultsKVEntry.md)
 - [PagedResultsLogEntry](docs/PagedResultsLogEntry.md)
 - [PagedResultsMapStringObject](docs/PagedResultsMapStringObject.md)
 - [PagedResultsMetricEntry](docs/PagedResultsMetricEntry.md)
 - [PagedResultsNamespace](docs/PagedResultsNamespace.md)
 - [PagedResultsSearchResultFlow](docs/PagedResultsSearchResultFlow.md)
 - [PagedResultsTenant](docs/PagedResultsTenant.md)
 - [PagedResultsTestSuite](docs/PagedResultsTestSuite.md)
 - [PagedResultsTestSuiteRunResult](docs/PagedResultsTestSuiteRunResult.md)
 - [PagedResultsTrigger](docs/PagedResultsTrigger.md)
 - [PagedResultsTriggerControllerTriggers](docs/PagedResultsTriggerControllerTriggers.md)
 - [PatchOperation](docs/PatchOperation.md)
 - [PatchOperationPath](docs/PatchOperationPath.md)
 - [PatchOperationType](docs/PatchOperationType.md)
 - [PatchRequest](docs/PatchRequest.md)
 - [Permission](docs/Permission.md)
 - [Plugin](docs/Plugin.md)
 - [PluginArtifact](docs/PluginArtifact.md)
 - [PluginArtifactMetadata](docs/PluginArtifactMetadata.md)
 - [PluginControllerApiPluginVersions](docs/PluginControllerApiPluginVersions.md)
 - [PluginDefault](docs/PluginDefault.md)
 - [PluginIcon](docs/PluginIcon.md)
 - [PluginPluginElementMetadata](docs/PluginPluginElementMetadata.md)
 - [PluginSchema](docs/PluginSchema.md)
 - [PluginSubGroupPluginCategory](docs/PluginSubGroupPluginCategory.md)
 - [PropertyAssetsDeclaration](docs/PropertyAssetsDeclaration.md)
 - [PropertyBoolean](docs/PropertyBoolean.md)
 - [PropertyDouble](docs/PropertyDouble.md)
 - [PropertyDuration](docs/PropertyDuration.md)
 - [PropertyListString](docs/PropertyListString.md)
 - [PropertyObject](docs/PropertyObject.md)
 - [PropertyString](docs/PropertyString.md)
 - [QueryFilter](docs/QueryFilter.md)
 - [QueryFilterField](docs/QueryFilterField.md)
 - [QueryFilterOp](docs/QueryFilterOp.md)
 - [RBACServiceRoleAssignmentRoleOrigin](docs/RBACServiceRoleAssignmentRoleOrigin.md)
 - [Relation](docs/Relation.md)
 - [Relation1](docs/Relation1.md)
 - [RelationType](docs/RelationType.md)
 - [ResourceType](docs/ResourceType.md)
 - [ResourceType1](docs/ResourceType1.md)
 - [ResourceTypeSchemaExtensionConfiguration](docs/ResourceTypeSchemaExtensionConfiguration.md)
 - [RightSidebarConfiguration](docs/RightSidebarConfiguration.md)
 - [RightSidebarConfigurationCustomLink](docs/RightSidebarConfigurationCustomLink.md)
 - [Role](docs/Role.md)
 - [RoleUsage](docs/RoleUsage.md)
 - [SLA](docs/SLA.md)
 - [SLABehavior](docs/SLABehavior.md)
 - [SLALabels](docs/SLALabels.md)
 - [SLAType](docs/SLAType.md)
 - [SchemaAttribute](docs/SchemaAttribute.md)
 - [SchemaAttributeMutability](docs/SchemaAttributeMutability.md)
 - [SchemaAttributeReturned](docs/SchemaAttributeReturned.md)
 - [SchemaAttributeType](docs/SchemaAttributeType.md)
 - [SchemaAttributeUniqueness](docs/SchemaAttributeUniqueness.md)
 - [SchemaType](docs/SchemaType.md)
 - [ScimExtension](docs/ScimExtension.md)
 - [ScimResource](docs/ScimResource.md)
 - [ScimResourceWithOptionalId](docs/ScimResourceWithOptionalId.md)
 - [ScimUser](docs/ScimUser.md)
 - [SearchRequest](docs/SearchRequest.md)
 - [SearchResultFlow](docs/SearchResultFlow.md)
 - [SecurityIntegrationType](docs/SecurityIntegrationType.md)
 - [ServerConfig](docs/ServerConfig.md)
 - [ServerConfigLiveness](docs/ServerConfigLiveness.md)
 - [ServerInstance](docs/ServerInstance.md)
 - [ServerInstanceType](docs/ServerInstanceType.md)
 - [ServiceInstance](docs/ServiceInstance.md)
 - [ServiceInstanceTimestampedEvent](docs/ServiceInstanceTimestampedEvent.md)
 - [ServiceProviderConfiguration](docs/ServiceProviderConfiguration.md)
 - [ServiceProviderConfigurationAuthenticationSchema](docs/ServiceProviderConfigurationAuthenticationSchema.md)
 - [ServiceProviderConfigurationAuthenticationSchemaType](docs/ServiceProviderConfigurationAuthenticationSchemaType.md)
 - [ServiceProviderConfigurationBulkConfiguration](docs/ServiceProviderConfigurationBulkConfiguration.md)
 - [ServiceProviderConfigurationFilterConfiguration](docs/ServiceProviderConfigurationFilterConfiguration.md)
 - [ServiceProviderConfigurationSupportedConfiguration](docs/ServiceProviderConfigurationSupportedConfiguration.md)
 - [ServiceServiceState](docs/ServiceServiceState.md)
 - [ServiceType](docs/ServiceType.md)
 - [SetAppsCatalogLogoRequest](docs/SetAppsCatalogLogoRequest.md)
 - [SetupConfiguration](docs/SetupConfiguration.md)
 - [SetupConfigurationSetupData](docs/SetupConfigurationSetupData.md)
 - [SortOrder](docs/SortOrder.md)
 - [SortRequest](docs/SortRequest.md)
 - [State](docs/State.md)
 - [StateHistory](docs/StateHistory.md)
 - [StateType](docs/StateType.md)
 - [Task](docs/Task.md)
 - [TaskFixture](docs/TaskFixture.md)
 - [TaskForExecution](docs/TaskForExecution.md)
 - [TaskRun](docs/TaskRun.md)
 - [TaskRunAttempt](docs/TaskRunAttempt.md)
 - [Tenant](docs/Tenant.md)
 - [TenantAppCatalogConfig](docs/TenantAppCatalogConfig.md)
 - [TenantControllerAppsCatalogConfigRequest](docs/TenantControllerAppsCatalogConfigRequest.md)
 - [TenantControllerAppsCatalogConfigResponse](docs/TenantControllerAppsCatalogConfigResponse.md)
 - [TenantInterface](docs/TenantInterface.md)
 - [TenantUsage](docs/TenantUsage.md)
 - [TestState](docs/TestState.md)
 - [TestSuite](docs/TestSuite.md)
 - [TestSuiteControllerRunRequest](docs/TestSuiteControllerRunRequest.md)
 - [TestSuiteControllerSearchTestsLastResult](docs/TestSuiteControllerSearchTestsLastResult.md)
 - [TestSuiteControllerTestSuiteApiId](docs/TestSuiteControllerTestSuiteApiId.md)
 - [TestSuiteControllerTestSuiteBulkRequest](docs/TestSuiteControllerTestSuiteBulkRequest.md)
 - [TestSuiteControllerTestsLastResultResponse](docs/TestSuiteControllerTestsLastResultResponse.md)
 - [TestSuiteRunResult](docs/TestSuiteRunResult.md)
 - [TestSuiteServiceRunByQueryRequest](docs/TestSuiteServiceRunByQueryRequest.md)
 - [TestSuiteServiceTestRunByQueryResult](docs/TestSuiteServiceTestRunByQueryResult.md)
 - [TheLabelsToPassToTheExecutionCreated](docs/TheLabelsToPassToTheExecutionCreated.md)
 - [TimeWindow](docs/TimeWindow.md)
 - [Trigger](docs/Trigger.md)
 - [TriggerContext](docs/TriggerContext.md)
 - [TriggerControllerSetDisabledRequest](docs/TriggerControllerSetDisabledRequest.md)
 - [TriggerControllerTriggers](docs/TriggerControllerTriggers.md)
 - [TriggerFixture](docs/TriggerFixture.md)
 - [Type](docs/Type.md)
 - [UnitTest](docs/UnitTest.md)
 - [UnitTestResult](docs/UnitTestResult.md)
 - [UploadVersionedPluginsRequest](docs/UploadVersionedPluginsRequest.md)
 - [UsageEE](docs/UsageEE.md)
 - [UserGroup](docs/UserGroup.md)
 - [UserGroupType](docs/UserGroupType.md)
 - [UserType](docs/UserType.md)
 - [UserUsage](docs/UserUsage.md)
 - [UsernamePasswordCredentials](docs/UsernamePasswordCredentials.md)
 - [ValidateConstraintViolation](docs/ValidateConstraintViolation.md)
 - [ValuePathExpression](docs/ValuePathExpression.md)
 - [WorkerGroup](docs/WorkerGroup.md)
 - [WorkerGroupFallback](docs/WorkerGroupFallback.md)
 - [WorkerTaskRestartStrategy](docs/WorkerTaskRestartStrategy.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basicAuth"></a>
### basicAuth

- **Type**: HTTP basic authentication

<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (Bearer)


## Author




